"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PaginationHelper = void 0;
const PER_PAGE_LIMIT = 50;
class PaginationHelper {
    static getPaginationQueryOptions(options) {
        const { pageNumber = 1, perPage, orderBy, orderDirection = 'asc', sortableFields = [], } = options;
        if (!sortableFields.includes(orderBy)) {
            throw new Error(`Informed field "${orderBy}" is not sortable.`);
        }
        if (!['asc', 'desc'].includes(orderDirection)) {
            throw new Error(`Informed field "${orderDirection}" is not valid.`);
        }
        const limit = Math.min(perPage, PER_PAGE_LIMIT);
        return {
            pageNumber,
            perPage: limit,
            orderBy,
            orderDirection,
            sortableFields,
        };
    }
    static getPaginatedResponse(opt) {
        const { data, currentPage, totalItems, itemsPerPage, } = opt;
        return {
            data,
            count: data.length,
            currentPage,
            perPage: itemsPerPage,
            total: totalItems,
            pages: Math.ceil(totalItems / itemsPerPage),
        };
    }
}
exports.PaginationHelper = PaginationHelper;
//# sourceMappingURL=paginationHelper.js.map